@@ -3,7 +3,7 @@
 import sys
 
 import moe
-from moe.config import Config
+from moe import config
 
 from . import import_cli, import_core
 from .import_cli import *
@@ -15,12 +15,12 @@ __all__.extend(import_core.__all__)
 
 
 @moe.hookimpl
-def plugin_registration(config: Config):
+def plugin_registration():
     """Only register the cli sub-plugin if the cli is enabled."""
-    config.plugin_manager.register(import_core, "import_core")
-    if config.plugin_manager.has_plugin("cli"):
-        config.plugin_manager.register(import_cli, "import_cli")
+    config.CONFIG.pm.register(import_core, "import_core")
+    if config.CONFIG.pm.has_plugin("cli"):
+        config.CONFIG.pm.register(import_cli, "import_cli")
 
     # re-register under the "import" name instead of "moe_import"
-    config.plugin_manager.unregister(name="moe_import")
-    config.plugin_manager.register(sys.modules[__name__], "import")
+    config.CONFIG.pm.unregister(name="moe_import")
+    config.CONFIG.pm.register(sys.modules[__name__], "import")
